.TH entrap L
.SH NAME
entrap \- a file integrity checker
.SH SYNOPSIS
.B entrap
[
.B \-c config_file
]
[
.B command
]
.SH DESCRIPTION
Entrap detects changes to files by comparing two snapshots and reporting the differences.
A snapshot is a of a list of file names and corresponding i-node characteristics, which may include one or more file signatures.
.P
When two snapshots are compared, Entrap generates a report showing how many files have been added, deleted, and modified relative to the snapshot on the left-hand-side of the comparison.
Entrap can also generate a detailed listing of the specific files and attributes that have changed.
Specific files and/or attributes can be ignored through the use of filtering rules.
.P
.SH OPTIONS
The following option is supported:
.P
.TP 5
.B \-c config_file

Entrap uses a configuration file to determine which directory trees should be included in a snapshot.
By default, Entrap uses a configuration file named entrap.
Alternate configuration files may be specified using the \-c option.

Each line in a configuration file is an ordered pair separated by white space.
The first element in the ordered pair is a directory path.
This is the root of a directory tree to be included in the snapshot.
All files included in the directory tree that belong to the same filesystem as the pathname will be included in the snapshot.
The second element in the ordered pair is the basename of a file used to store snapshot data for the specified directory tree.

.SH COMMANDS
The following commmands are supported:
.P
.TP 5
.B snapshot [\-o] snapshot_name

The snapshot command is used to take a snapshot. 
A snapshot is composed of a directory containing one or more files.
Existing snapshot files are not overwritten unless the \-o option is used.

A snapshot file consists of data organized in rows and columns.
There is one rows for each file included in the snapshot.
Each column corresponds to a specific file attribute.
.TP 5
.B filter [\-f filter_name] snapshot

The filter command applies filtering rules to the specified snapshot.
A given snapshot only needs to be filtered once for a given filter.
After it has been filered, the snapshot may be compared against other snapshots multiple times without being filtered again.
However, if the filtering rules change, the snapshot will need to be filtered again.

By default, Entap uses the filter named entrap.
Alternate filters may be specified using the \-f option.

A filter is composed of a directory containing one or more filter files.
The files in a filter directory must be named the same as the directory aliases listed in a corresponding configuration file.
If a filter file does not already exist, Entrap will create an empty file with the appropriate name when the filter command is run.
When using multiple filters, make sure the filter being applied to a particular snapshot is compatible with the configuration file used to create the snapshot.

Each line in a filter file is formatted as follows: PATHNAME MATCHTYPE ATTRIBUTES.

PATHNAME is either the complete pathname of a file or directory, or a pathname prefix.

Valid values for MATCHTYPE are "exact" and "prefix".
If MATCHTYPE equals "exact", then the filtering rule will only apply to the file or directory who's pathname matches PATHNAME exactly.
If MATCHTYPE equals "prefix", then the filtering rule will apply to all files and directories who's pathnames begin with the prefix PATHNAME.

ATTRIBUTES is a string of one or more characters.
Certain alpha-numeric characters tell Entrap to ignore specific attributes when comparing two snapshots.
The characters * and ! are wild cards with special meaning.
The following characters are valid:

i = inode

p = protection mode

l = number of links

o = owner

g = group

s = size (in bytes)

m = modification time

1 = first file signature

2 = second file signature

3 = third file signature

4 = fourth file signature

* = ignore all attribute changes, but detect file creations and deletions

! = ignore all attribute changes as well as file creations and deletions

.TP 5
.B compare [\-fv] snapshot1 snapshot2

The compare command compares two snapshots and summarizes the differences.
If the \-f option is used, Entrap compares filtered snapshots.
Without the \-f option, unfiltered snapshots are compared and all differences are reported.
The filter command must be executed before two filtered snapshots can be compared.

When the \-v option is used, a verbose report is produced, which includes a list of all files that have been added, modified, or deleted.
Without the \-v option, a summary report is produced, which only lists the number of files that have been added, modified, or deleted.
.SH DIRECTORIES
.TP 5
.B /opt/entrap

By default, the "root" directory for Entrap is assumed to be /opt/entrap.
If Entrap is installed in some other directory, then you must modify the global constant ENTRAP_DIR in ~/bin/entrap.
.TP 5
.B ~/bin

The bin directory contains the Entrap shell scripts.
.TP 5
.B ~/etc

The etc directory contains two subdirectories: conf and filters.
.TP 5
.B ~/etc/conf

The conf directory contains one or more Entrap configuration files.
.TP 5
.B ~/etc/filters

The filters directory contains one subdirectory for each filter.
.TP 5
.B ~/var

The var directory contains two subdirectories: snapshots and tmp.
You may want to link ~/var to another directory such as /var/opt/entrap/var.
.TP 5
.B ~/var/snapshots

The snapshots directory contains one subdirectory for each snapshot.
.TP 5
.B ~/var/tmp

The tmp directory is where Entrap stores various temporary files that are removed when the program terminates normally.
Files may remain in this directory if Entrap is interrupted unexpectedly.
Since these files can be relatively large, Entrap attempts to clean up old temporary files the next time the program is run.
.TP 5
.B ~/man

The man directory contains the source for this man page.
.SH FILES
.TP 5
.B ~/README

The README file explains how to install this man page.
.TP 5
.B ~/bin/entrap

This script is the only program that you ever need to call directly.
It contains several global constants.
If Entrap is installed in a directory other than /opt, then you must modify the global constant ENTRAP_DIR.
.TP 5
.B ~/bin/attributes.sh

This script prints the attributes for a given file.
It must be modified in order to "turn on" specific file signatures.
.TP 5
.B ~/etc/conf/entrap

This is the default configuration file.
.SH EXAMPLES
.TP 5
Create ~/var/snapshots/sample_snapshot1:
entrap -c sample_conf snapshot sample_snapshot1
.TP 5
Filter sample_snapshot1:
entrap -c sample_conf filter -f sample_filter sample_snapshot1
.TP 5
Compare sample_snapshot1 vs. sample_snapshot2:
entrap -c sample_conf compare sample_snapshot1 sample_snapshot2
.SH BUGS
Entrap was developed for and tested on a Solaris 7 system.
Modifications may be necessary in order for Entrap to work on other versions of Unix.
.TP 5
In particular:

Depending on how the command "ls -ild" formats its output, you may have to modify ~/bin/attributes.sh.

Some of the checksum programs in ~/bin/attributes.sh may not exist and/or you may have to modify some of the pathnames.

The ckyorn command used in ./bin/entrap may not exist.
.P
Entrap is sensitive to spaces.
Spaces in file names and the unexpected presence or absence of spaces in the output of "ls -ild" may cause problems.
.SH SEE ALSO
find(1), ls(1), diff(1), sum(1), sum(1B), cksum(1)
.SH RELATED LINKS
Tripwire
.br
http://www.tripwire.com
.P
AIDE (Advanced Intrusion Detection Environment)
.br
http://www.cs.tut.fi/~rammer/aide.html
.P
ICU (Integrity Checking Utility)
.br
http://www.algonet.se/~nitzer/ICU/ 
.P
Osirus (a file integrity verification system)
.br
http://www.shmoo.com/osiris/ 
.P
Samhain (a file integrity and intrusion detection tool)
.br
http://samhain.sourceforge.net/ 
.P
md5 (file signature utility)
.br
http://www.sun.com/blueprints/tools/md5.html
.P
The Solaris Fingerprint Database
.br
http://www.sun.com/blueprints/0501/Fingerprint.pdf 
.P
CERT List of Security Tools
.br
http://www.cert.org/tech_tips/security_tools.html
.P
CIAC System Monitoring Tools
.br
http://ciac.llnl.gov/ciac/ToolsUnixSysMon.html
.SH REVISION HISTORY
Version 1.0.0 released on 3 Feb 2002
.SH AUTHOR
.br
John Spurgeon (john.p.spurgeon@intel.com)
